@@ -26,18 +26,19 @@ DATASET_MAP = {'s4_formula': ('7341_C1.csv', ',', False ,'7341_C1 desc.txt'),
 'cheese': ('Cheese_RAMAN.csv',',',True,'Cheese_RAMAN desc.txt'),
 'huangjing': ('7a43.csv',',',True,'7a43 desc.txt'),
 'chaihu': ('7a40.csv',',',True,'7a40 desc.txt'),
+'rice_cereal':('7741_rice_cereal_rm.csv',',',True,'7741_rice_cereal_rm desc.txt'),
 'organic_milk': ('MALDITOFMS_ORGANICMILK_7047_C02.csv',',',True,'MALDITOFMS_ORGANICMILK_7047_C02 desc.txt'),}
 
 def get_available_datasets():
     return list( DATASET_MAP.keys() )
 
-def DataSetIdToPath(id):
+def id_to_path(id):
     return DATASET_MAP[id]
 
-def LoadDataSet(id, SD = 1, shift = 200):
+def load_dataset(id, SD = 1, shift = 200, x_range = None):
     
-    path, delimiter, has_y, path_desc = DataSetIdToPath(id)
-    X, y, X_names = PeekDataSet(DATA_FOLDER + path, delimiter, has_y, SD, shift)
+    path, delimiter, has_y, path_desc = id_to_path(id)
+    X, y, X_names = PeekDataSet(DATA_FOLDER + path, delimiter, has_y, SD, shift, x_range)
     
     if os.path.exists (DATA_FOLDER + path_desc):
         f=open(DATA_FOLDER + path_desc, "r", encoding = 'UTF-8')
@@ -51,11 +52,12 @@ def LoadDataSet(id, SD = 1, shift = 200):
     
     return X, y, X_names, desc
 
-def OpenDataSet(path, delimiter = ',', has_y = True):
+def open_dataset(path, delimiter = ',', has_y = True, x_range = None):
     '''
     Parameters
     ----------
     has_y : boolean, whether there is y column, usually the 1st column.
+    x_range : [250,2000] or None. If none, all features are kept.
     '''
 
     # path = "github/data/754a_C2S_Beimu.txt"
@@ -80,20 +82,24 @@ def OpenDataSet(path, delimiter = ',', has_y = True):
         # use map(float, ) to convert the string list to float list
         X_names = list(map(float, data.columns.values)) # X_names = np.array(list(data)[1:])
 
+    if x_range is not None:
+        X = X[:,x_range]
+        X_names = np.array(X_names)[x_range].tolist()
+
     cnt_nan = np.isnan (X).sum()
     if cnt_nan > 0:
         print('Found' + str(cnt_nan) + 'NaN elements in X. You may need to purge NaN.')
 
     return X, y, X_names
 
-def ScatterPlot(X, y):    
+def scatter_plot(X, y):    
 
     pca = PCA(n_components=2) # keep the first 2 components
     X_pca = pca.fit_transform(X)
     plotComponents2D(X_pca, y)
     plt.show()
 
-def Draw_Average (X, X_names, SD = 1):
+def draw_average (X, X_names, SD = 1):
 
     matplotlib.rcParams.update({'font.size': 16})
 
@@ -120,7 +126,7 @@ def Draw_Average (X, X_names, SD = 1):
     matplotlib.rcParams.update({'font.size': 12})
 
 
-def Draw_All (X, X_names, titles = None):
+def draw_all (X, X_names, titles = None):
 
     matplotlib.rcParams.update({'font.size': 16})
 
@@ -140,7 +146,7 @@ def Draw_All (X, X_names, titles = None):
     matplotlib.rcParams.update({'font.size': 12})
 
 
-def Draw_Class_Average (X, y, X_names, SD = 1, shift = 200):
+def draw_class_average (X, y, X_names, SD = 1, shift = 200):
     '''
     Parameter
     ---------
@@ -181,16 +187,16 @@ def Draw_Class_Average (X, y, X_names, SD = 1, shift = 200):
 
     matplotlib.rcParams.update({'font.size': 10})
 
-def PeekDataSet(path,  delimiter = ',', has_y = True, SD = 1, shift = 200):
+def peek_dataset(path,  delimiter = ',', has_y = True, SD = 1, shift = 200, x_range = None):
 
-    X, y, X_names = OpenDataSet(path, delimiter=delimiter, has_y = has_y)
+    X, y, X_names = open_dataset(path, delimiter=delimiter, has_y = has_y, x_range = x_range)
 
     if y is None:
-        Draw_Average (X, X_names)
+        draw_average (X, X_names)
     else:
-        Draw_Class_Average (X, y, X_names, SD, shift)
+        draw_class_average (X, y, X_names, SD, shift)
 
-    ScatterPlot(X, y)
+    scatter_plot(X, y)
     
     return X, y, X_names
 
@@ -207,7 +213,7 @@ def Upsample(target_path, X, y, X_names, folds = 3, d = 0.5):
 
     SMOTE.expand_dataset(X, y, X_names, target_path, d, folds)
 
-def SaveDataSet(targe_path, X, y, X_names):
+def save_dataset(targe_path, X, y, X_names):
     '''
     Save X, y to a local csv file.
 
